@@ -549,13 +549,13 @@ class DenMune():
       
            if self.data_indicator >= 3:
                self.analyzer["validity"] = {}
+               self.analyzer["validity"]['train'] = {}
                validity_scores = self.validate_Clusters(data_type='train') 
          
            if show_analyzer:
                print ('Plotting train data')  
            self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='train')
            if show_analyzer:
-              self.analyzer["validity"]['train'] = {}
               self.show_Analyzer(root='Validating train data')   
 
            if self.data_indicator == 15:
@@ -581,7 +581,10 @@ class DenMune():
                    print ('Plotting augmented data (train & test)')  
                self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='augmented')
            """
-        return labels_dic, self.analyzer['validity']
+        if self.data_indicator  == 1:
+            return labels_dic, None
+        else:
+            return labels_dic, self.analyzer['validity']
         
 
 
